import * as Rx from 'rxjs';
import { Loader, Textarea, Comment, RefreshIcon } from './styles';
import * as React from 'react';

/**
 * Component for entering new reviews
 */
class NewReviewBox extends React.Component<NewReviewBoxProps, NewReviewBoxStates> {

    private static LOADING: NewReviewBoxStates = { loading: true };
    private static NOT_LOADING = { loading: false, txt: '' };

    public constructor(props: NewReviewBoxProps) {
        super(props);
        this.state = NewReviewBox.NOT_LOADING;
    }

    public setLoadingState() {
        this.setState(NewReviewBox.LOADING);
    }

    public removeLoadingState() {
        const noloadingState = NewReviewBox.NOT_LOADING;
        noloadingState.txt = '';
        this.setState(noloadingState);
    }

    public setText = (ev: any) => {
        const noloadingState = NewReviewBox.NOT_LOADING;
        noloadingState.txt = (ev.target as HTMLTextAreaElement).value;
        this.setState(noloadingState);
        this.props.setText((ev.target as HTMLTextAreaElement).value);
    }

    public analizeReview = () => {
        this.setLoadingState();
        (this.props.analize() as Rx.Observable<AnalizedResponse>).subscribe(
            data => {
                if (data.status !== 'OK') {
                    console.error('Something went wrong while analizing text', data);
                }
                this.props.setText('');
                this.getReviewsForInitialPage();
            },
            (error) => { console.error('Analized failed', error); });
    }

    public getReviewsForInitialPage = () => {
        (this.props.getReviewsForPage(0) as Rx.Observable<AnalizedsPage>).subscribe(
            (data: AnalizedsPage) => {
                if (this.props.parent)
                    this.props.parent.changeReviews(data);
                this.removeLoadingState();
            },
            (error) => { console.error('Error while loading initial reviews') }
        );
    }

    public render() {
        let textarea: JSX.Element;
        let loader: JSX.Element;

        if (!this.props.hide) {
            textarea = <Textarea value={this.state.txt} disabled={this.props.disable} onChange={this.setText} className="review-body" placeholder={this.props.disable ? 'Register to send reivews' : 'Your comment'}></Textarea>
        }

        if (this.state.loading) {
            loader = <div id="loading"><Loader></Loader></div>;
        }

        return (
            <Comment className="review">
                <div className="comment-header">
                    <a href="javascript: void(0);" onClick={this.analizeReview}>
                        <i className="fa fa-paper-plane-o fa-2x" aria-hidden="true"></i>
                    </a>
                </ div>
                {textarea}
                {loader}
            </Comment>
        );
    }
};
export default NewReviewBox;