import * as Rx from 'rxjs';
import { Loader, Textarea, Comment, RefreshIcon } from './styles';
import * as React from 'react';

/**
 * Paginating component
 */
class OlderReviewsBox extends React.Component<OlderReviewsBoxProps, OlderReviewsBoxStates>{

    private static LOADING: OlderReviewsBoxStates = { loading: true };
    private static NOT_LOADING:OlderReviewsBoxStates = { loading: false};

    public constructor(props: OlderReviewsBoxProps) {
        super(props);
        this.state = OlderReviewsBox.NOT_LOADING;
    }

    public addMore = () => {
        this.setState(OlderReviewsBox.LOADING);
        (this.props.addMore() as Rx.Observable<AnalizedsPage>).subscribe(
            (data: AnalizedsPage) => {
                this.setState(OlderReviewsBox.NOT_LOADING);
                this.props.parent.addReviews(data);
            },
            (error)=> {
                console.error('Error while loading more reviews')
            }
        );
    }

    public getReviewsForPage = (page: number) => {
        this.setState(OlderReviewsBox.LOADING);
        (this.props.getReviewsForPage(page) as Rx.Observable<AnalizedsPage>).subscribe(
            (data: AnalizedsPage) => {
                this.setState(OlderReviewsBox.NOT_LOADING);
                this.props.parent.changeReviews(data);
            },
            (error)=> {
                console.error('Error while loading more reviews')
            }
        );
    }

    public render() {

        let nextButton: JSX.Element;
        let lastButton: JSX.Element;
        let firstButton: JSX.Element;
        let previousButton: JSX.Element;
        let showMoreButton: JSX.Element;

        if (this.props.showMoreApproach && (this.props.paging.currentPage < this.props.paging.lastPage)) {
            showMoreButton = <a href="javascript: void(0);" onClick={this.addMore}>
                 {this.state.loading ?
                    <i className='fa fa-refresh fa-2x' aria-hidden="true"></i> : <RefreshIcon className='fa fa-refresh fa-2x' aria-hidden="true"></RefreshIcon>
                 }
            </a>;
        } else if (!this.props.showMoreApproach) {
            if (this.props.paging.currentPage + 1 < this.props.paging.lastPage) {
                nextButton = <a href="javascript: void(0);" onClick={() => this.getReviewsForPage(this.props.paging.currentPage + 1)}>
                    <i className="fa fa-forward fa-2x" aria-hidden="true"></i>
                </a>;
            }
            if (this.props.paging.currentPage > 1) {
                previousButton = <a href="javascript: void(0);" onClick={() => this.getReviewsForPage(this.props.paging.currentPage - 1)}>
                    <i className="fa fa-backward fa-2x" aria-hidden="true"></i>
                </a>;
            }
            if (this.props.paging.currentPage < this.props.paging.lastPage) {
                lastButton = <a href="javascript: void(0);" onClick={() => this.getReviewsForPage(this.props.paging.lastPage)}>
                    <i className="fa fa-fast-forward fa-2x" aria-hidden="true"></i>
                </a>;
            }
            if (this.props.paging.currentPage > 0) {
                firstButton = <a href="javascript: void(0);" onClick={() => this.getReviewsForPage(0)}>
                    <i className="fa fa-fast-backward fa-2x" aria-hidden="true"></i>
                </a>;
            }
        }

        return (
            <div className="reviews-pageable">
                {firstButton}
                {previousButton}
                {nextButton}
                {lastButton}
                {showMoreButton}
            </div>
        );
    }
};
export default OlderReviewsBox;
