var Rx = require('rxjs');
var ReactTestUtils = require('react-dom/test-utils');

var OctoClient = require('../dist/octoClient');
window.octoClient._buildComponent = jest.fn();

beforeEach(()=> {
    window.octoClient._buildComponent.mockReset();
});

test('Calls to retrieve new list of reviews once text is bieng analyzed and insertLastReviews is set to true', () => {
    mockRxCallWithStatus('OK');
    window.octoClient.setOptions({ pageSize: 5, insertLastReviews: true, userKey: 'my_user', hideWhenNotLogged: false, disableWhenNotLogged: false, dateFormat: 'YYYY-MM-DD', showMoreApproach: false });
    window.octoClient.analize();
    expect(window.octoClient._buildComponent).toBeCalledWith(0);
});

test('Does not call to retrieve new list of reviews once text is bieng analyzed and insertLastReviews is set to false', () => {
    mockRxCallWithStatus('OK');
    window.octoClient.setOptions({ pageSize: 5, insertLastReviews: false, userKey: 'my_user', hideWhenNotLogged: false, disableWhenNotLogged: false, dateFormat: 'YYYY-MM-DD', showMoreApproach: false });
    window.octoClient.analize();
    expect(window.octoClient._buildComponent).not.toBeCalled();
});

test('Does not call to retrieve new list of reviews once text analyze has failed', () => {
    mockRxCallWithStatus('FAIL');
    window.octoClient.setOptions({ pageSize: 5, insertLastReviews: false, userKey: 'my_user', hideWhenNotLogged: false, disableWhenNotLogged: false, dateFormat: 'YYYY-MM-DD', showMoreApproach: false });
    window.octoClient.analize();
    expect(window.octoClient._buildComponent).not.toBeCalled();
});

function mockRxCallWithStatus(status) {
    Rx.Observable.ajax.getJSON = jest.fn((url) => { 
        return { 
            retry: (retries) => {
                return { map : (callback) => { callback({ status: status})}};
            }
        }
    });
}